Py4JClientConnection (py4j-java 0.10.9.7 API)

Package py4j

## Interface Py4JClientConnection

- All Known Implementing Classes:
    `CallbackConnection`, `ClientServerConnection`

      public interface Py4JClientConnection

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `java.lang.String` | `sendCommand​(java.lang.String command)` |
    `java.lang.String` | `sendCommand​(java.lang.String command, boolean blocking)` |
    `void` | `setUsed​(boolean used)` |
    `void` | `shutdown()` |
    `void` | `shutdown​(boolean reset)` |
    `void` | `start()` |
    `boolean` | `wasUsed()` |

- - ### Method Detail

    - #### sendCommand

          java.lang.String sendCommand​(java.lang.String command)

    - #### sendCommand

          java.lang.String sendCommand​(java.lang.String command,
                                       boolean blocking)

    - #### shutdown

          void shutdown()

    - #### shutdown

          void shutdown​(boolean reset)

    - #### start

          void start()
              throws java.io.IOException

      Throws:
        `java.io.IOException`

    - #### setUsed

          void setUsed​(boolean used)

    - #### wasUsed

          boolean wasUsed()